==> adalid-alfa-2.1.0-sources.jar: adalid/core/properties/LongProperty.java <==
/*
 * Copyright 2017 Jorge Campins y David Uzcategui
 *
 * Este archivo forma parte de Adalid.
 *
 * Adalid es software libre; usted puede redistribuirlo y/o modificarlo bajo los terminos de la
 * licencia "GNU General Public License" publicada por la Fundacion "Free Software Foundation".
 * Adalid se distribuye con la esperanza de que pueda ser util, pero SIN NINGUNA GARANTIA; sin
 * siquiera las garantias implicitas de COMERCIALIZACION e IDONEIDAD PARA UN PROPOSITO PARTICULAR.
 *
 * Para mas detalles vea la licencia "GNU General Public License" en http://www.gnu.org/licenses
 */
package adalid.core.properties;

import adalid.core.annotations.BaseField;
import adalid.core.annotations.CastingField;
import adalid.core.annotations.ColumnField;
import adalid.core.annotations.NumericDataGen;
import adalid.core.annotations.NumericField;
import adalid.core.annotations.PrimaryKey;
import adalid.core.annotations.PropertyAggregation;
import adalid.core.annotations.PropertyField;
import adalid.core.annotations.SequenceProperty;
import adalid.core.annotations.UniqueKey;
import adalid.core.annotations.VersionProperty;
import adalid.core.data.types.LongData;
import adalid.core.interfaces.Property;
import java.lang.annotation.Annotation;
import java.util.List;

/**
 * @author Jorge Campins
 */
public class LongProperty extends LongData implements Property {

    @Override
    protected List<Class<? extends Annotation>> getValidFieldAnnotations() {
        List<Class<? extends Annotation>> valid = super.getValidFieldAnnotations();
        valid.add(BaseField.class);
        valid.add(CastingField.class);
        valid.add(ColumnField.class);
        valid.add(NumericDataGen.class);
        valid.add(NumericField.class);
        valid.add(PrimaryKey.class);
        valid.add(PropertyField.class);
        valid.add(PropertyAggregation.class);
        valid.add(SequenceProperty.class);
        valid.add(UniqueKey.class);
        valid.add(VersionProperty.class);
        return valid;
    }

}

==> adalid-alfa-4.8.0-sources.jar: adalid/core/properties/LongProperty.java <==
/*
 * Copyright 2017 Jorge Campins y David Uzcategui
 *
 * Este archivo forma parte de Adalid.
 *
 * Adalid es software libre; usted puede redistribuirlo y/o modificarlo bajo los terminos de la
 * licencia "GNU General Public License" publicada por la Fundacion "Free Software Foundation".
 * Adalid se distribuye con la esperanza de que pueda ser util, pero SIN NINGUNA GARANTIA; sin
 * siquiera las garantias implicitas de COMERCIALIZACION e IDONEIDAD PARA UN PROPOSITO PARTICULAR.
 *
 * Para mas detalles vea la licencia "GNU General Public License" en http://www.gnu.org/licenses
 */
package adalid.core.properties;

import adalid.core.annotations.*;
import adalid.core.data.types.*;
import adalid.core.interfaces.*;
import java.lang.annotation.Annotation;
import java.util.List;

/**
 * @author Jorge Campins
 */
public class LongProperty extends LongData implements NumericProperty {

    @Override
    protected List<Class<? extends Annotation>> getValidFieldAnnotations() {
        List<Class<? extends Annotation>> valid = super.getValidFieldAnnotations();
        valid.add(BaseField.class);
        valid.add(CastingField.class);
        valid.add(ColumnField.class);
        valid.add(NumericDataGen.class);
        valid.add(NumericField.class);
        valid.add(PrimaryKey.class);
        valid.add(PropertyField.class);
        valid.add(PropertyAggregation.class);
        valid.add(SegmentProperty.class); // since 20210218
        valid.add(SequenceProperty.class);
        valid.add(UniqueKey.class);
        valid.add(VersionProperty.class);
        return valid;
    }

}
